<?php

namespace Drupal\custom_library\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Custom Library settings for this site.
 *
 * @internal
 */
class CustomLibraryConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'custom_library_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['custom_library.assets.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('custom_library.assets.settings');

    $form['description'] = [
      '#markup' => $this->t('This form is used to configure Advanced library settings for our site'),
    ];

    $form['enable_custom_asset'] = [
      '#type' => 'checkbox',
      '#title' => 'Enable Custom Library',
      '#default_value' => $config->get('enable_custom_asset'),
    ];

    $form['css_asset_links'] = [
      '#type' => 'textarea',
      '#title' => 'CSS Asset Links',
      '#default_value' => $config->get('css_asset_links'),
      '#maxlength' => 200,
      '#description' => $this->t('Enter the external links for CSS Libraries with comma'),
    ];

    $form['js_asset_links'] = [
      '#type' => 'textarea',
      '#title' => 'JS Asset Links',
      '#default_value' => $config->get('js_asset_links'),
      '#maxlength' => 200,
      '#description' => $this->t('Enter the external links for JS Libraries with comma'),
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save configuration'),
      '#button_type' => 'primary',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('custom_library.assets.settings')
      ->set('enable_custom_asset', $form_state->getValue('enable_custom_asset'))
      ->set('css_asset_links', $form_state->getValue('css_asset_links'))
      ->set('js_asset_links', $form_state->getValue('js_asset_links'))
      ->save();

    parent::submitForm($form, $form_state);
    drupal_flush_all_caches();

  }

}
